@@ -6,11 +6,11 @@
 * @パッケージ：-
 * @作者：(IIS)J.Hashimoto
 * @作成日/作成者：2006/09/01 (IIS)J.Hashimoto
-* @更新日/更新者：
-* @バージョン：1.0.0
+* @更新日/更新者：2007/03/01 (IIS)J.Fujikawa
+* @バージョン：1.1.0
 *
-*  Copyright (c) 2006 Iwate Information System Co.,Ltd. All Rights Reserved.
-*  You may see the License at LICENSE_EN.txt(English) or LICENSE_JA.txt(Japanese).
+* Copyright (c) 2006-2007 Iwate Information System Co.,Ltd. All Rights Reserved.       
+* You may see the License at LICENSE_EN.txt(English) or LICENSE_JA.txt(Japanese). 
 */ 
 
 require_once("../DefineDirectryName.php");							//Directory(PREFIX)読み込み
@@ -45,11 +45,9 @@ $errorMessage = null;
 $agent	=	false;
 
 /* テスト用*/
-$dmy = "a";
-switch($dmy){
-
-
-//switch(user_agent()){
+//$dmy = "a";
+//switch($dmy){
+switch(user_agent()){
 	case "a":
 		$agent	=	true;
 		break;
@@ -239,12 +237,21 @@ if ($agent){
 //						$fileName = str_replace("/", "_", crypt(date('YmdHis', time()).(((float)$msec)*1000000), "kakikomap") . $fileExtension);
 						$fileName = date('YmdHis', time()).(((float)$msec)*1000000) . $fileExtension;
 						if ($updMode == "0"){
-
+							//実ファイル削除
+							if ( deleteMemoImgFile($memoId, $s_UserId) == FALSE){
+								trigger_error("Comment Data Invalid Error!!", E_USER_ERROR);
+								exit();					
+							}
 							if (updateMemo($memoId, $fileName)  == FALSE){
 								trigger_error("Memo Modify Error", E_USER_ERROR);
 								exit();
 							}
 						}else{
+							//実ファイル削除
+							if ( deleteCommentImgFile($commentId) == FALSE){
+								trigger_error("Comment Data Invalid Error!!", E_USER_ERROR);
+								exit();					
+							}
 							if (updateComment($commentId, $fileName) == FALSE){
 								trigger_error("Comment Modify Error", E_USER_ERROR);
 								exit();
@@ -322,8 +329,51 @@ if ($agent){
 
 	}
 
-	//正常の場合、トップページへRedirect
-    header("location: ./index.php");
+	//画像削除にチェックが入っている場合
+	if ( (array_key_exists( "delete",	$_POST))
+		&& (array_key_exists( "memoId",	$_POST)) ){
+
+		$del_flg = postInfo("delete");
+
+		if ((array_key_exists( "commentId",	$_POST))) {
+			//コメント
+			$postCommentId = postInfo("commentId");
+			
+			if ($del_flg != ""){
+				//実ファイル削除
+				if ( deleteCommentImgFile($postCommentId) == FALSE){
+					trigger_error("Comment Data Invalid Error!!", E_USER_ERROR);
+					exit();					
+				}
+								
+				$uploadfileName = "";
+				
+				//DB上のファイル名削除
+				updateComment($postCommentId, $uploadfileName);
+			}
+			
+		}else{
+			//メモ
+			$postMemoId = postInfo("memoId");
+			
+			if ($del_flg != ""){
+				//実ファイル削除
+				if ( deleteMemoImgFile($postMemoId, $s_UserId) == FALSE){
+					trigger_error("Comment Data Invalid Error!!", E_USER_ERROR);
+					exit();					
+				}
+				
+				$uploadfileName = "";
+				
+				//DB上のファイル名削除
+				updateMemo($postMemoId, $uploadfileName);
+			}
+		}
+	
+	}
+
+//	正常の場合、メイン画面へRedirect
+    header("location: ./main.php");
 	exit();
 }
 
@@ -628,4 +678,75 @@ function updateComment($commentid, $filename){
 	return TRUE;
 }
 
+/**
+* 関数概要	：メモの画像ファイル削除
+* 処理詳細	：メモの画像ファイルを削除する
+*
+* @引数		：	(I) memoId		- メモID
+*				(I) userId		- ユーザーID
+* @戻値		：	bool			- TRUE	正常
+*								- FALSE	異常
+*
+* @作成日/作成者：2007/03/01 (IIS)J.Fujikawa
+* @更新日/更新者：
+* @更新内容	：
+*/
+function deleteMemoImgFile($memoId, $userId){
+
+	// 詳細情報を取得
+	$viewService		=	new ContentsViewService(DIRECTORY_NAME);
+	$memoDetailRecord	=	new MemoDetailPositionTypeData;
+	$memoDetailRecord	=	$viewService->getOneMemoDetailViewDataAuth($memoId, $userId);
+	
+	if (is_null($memoDetailRecord)){
+		trigger_error("Memo Data Invalid Error!!", E_USER_ERROR);
+		return FALSE;
+	}
+	
+	//実ファイル削除
+	$uploadfileName = $memoDetailRecord->getImageFile_d();
+	if (empty($uploadfileName) == FALSE){
+		if (file_exists(MOBILE_IMG_DIR . $memoDetailRecord->getImageFile_d())){
+			unlink(MOBILE_IMG_DIR . $memoDetailRecord->getImageFile_d());
+		}
+	}
+ 
+	return TRUE;
+}
+
+/**
+* 関数概要	：コメントの画像ファイル削除
+* 処理詳細	：コメントの画像ファイルを削除する
+*
+* @引数		：	(I) commentId	- コメントID
+* @戻値		：	bool			- TRUE	正常
+*								- FALSE	異常
+*
+* @作成日/作成者：2007/03/01 (IIS)J.Fujikawa
+* @更新日/更新者：
+* @更新内容	：
+*/
+function deleteCommentImgFile($commentId){
+
+	// 詳細情報を取得
+ 	$viewService	=	new ContentsViewService(DIRECTORY_NAME);
+	$commentDetailRecord	=	new MemoDetailPositionTypeData;
+	$commentDetailRecord	=	$viewService->getOneCommentData($commentId);
+	
+	if (is_null($commentDetailRecord)){
+		trigger_error("Comment Data Invalid Error!!", E_USER_ERROR);
+		return FALSE;
+	}
+	
+	//実ファイル削除
+	$uploadfileName = $commentDetailRecord->getImageFile_c();
+	if (empty($uploadfileName) == FALSE){
+		if (file_exists(MOBILE_IMG_DIR . $commentDetailRecord->getImageFile_c())){
+			unlink(MOBILE_IMG_DIR . $commentDetailRecord->getImageFile_c());
+		}
+	}
+
+	return TRUE;
+}
+
 ?>
\ No newline at end of file
