@@ -5,10 +5,10 @@
 * @パッケージ：-
 * @作者：h.keta
 * @作成日/作成者：2006/09/01 (IIS)h.keta
-* @更新日/更新者：
-* @バージョン：1.0.0
+* @更新日/更新者：2007/03/01 (IIS)J.Fujikawa
+* @バージョン：1.1.0
 *
-* Copyright (c) 2006 Iwate Information System Co.,Ltd. All Rights Reserved.       
+* Copyright (c) 2006-2007 Iwate Information System Co.,Ltd. All Rights Reserved.       
 * You may see the License at LICENSE_EN.txt(English) or LICENSE_JA.txt(Japanese). 
 */ 
 
@@ -67,7 +67,9 @@ $label = array(
     "helpLink"      => $o_resource->getValue("G03006L032"),
     "refBtn"        => $o_resource->getValue("G03006L033"),
     "addBtn"        => $o_resource->getValue("G03006L034"),
-    "rstBtn"        => $o_resource->getValue("G03006L035")
+    "rstBtn"        => $o_resource->getValue("G03006L035"),
+    "pc"     		=> $o_resource->getValue("G03006L036"),
+    "mobile"        => $o_resource->getValue("G03006L037")
 );
 
 
@@ -80,6 +82,9 @@ $o_service = new MapAdminService($o_tablename->get_DirectryName());
 // 画像サイズ初期値(推奨値)
 $mapSizeHorizontal = 600;
 $mapSizeVertical = 480;
+// 画像サイズ初期値(携帯用:推奨値)
+$mapSizeHorizontalMobile = 200;
+$mapSizeVerticalMobile = 160;
 
 // QuickForm インスタンス化
 $o_form = new HTML_QuickForm("basemapset", "POST", $_SERVER["PHP_SELF"]);
@@ -107,6 +112,15 @@ if (!isset($_POST['usegis_group']['usegis'])) {
 	if ($mapdata[0]->getMapSizeVertical_BaseMap() != 0){
 		$mapSizeVertical = $mapdata[0]->getMapSizeVertical_BaseMap();
 	}
+
+	if ($mapdata[0]->getMapSizeHorizontalMobile_BaseMap() != 0){
+		$mapSizeHorizontalMobile = $mapdata[0]->getMapSizeHorizontalMobile_BaseMap();
+	}
+
+	if ($mapdata[0]->getMapSizeVerticalMobile_BaseMap() != 0){
+		$mapSizeVerticalMobile = $mapdata[0]->getMapSizeVerticalMobile_BaseMap();
+	}
+	
 }
 
 // 入力項目のデフォルトをセット
@@ -120,11 +134,15 @@ $form_def = array(
 //    "mapsizevertical"                    => isset($_POST['mapsizevertical'])?$_POST['mapsizevertical']:$mapdata[0]->getMapSizeVertical_BaseMap(),
     "mapsizehorizontal"                  => isset($_POST['mapsizehorizontal'])?$_POST['mapsizehorizontal']:$mapSizeHorizontal,
     "mapsizevertical"                    => isset($_POST['mapsizevertical'])?$_POST['mapsizevertical']:$mapSizeVertical,
+    "mapsizehorizontal_mobile"                  => isset($_POST['mapsizehorizontal_mobile'])?$_POST['mapsizehorizontal_mobile']:$mapSizeHorizontalMobile,
+    "mapsizevertical_mobile"                    => isset($_POST['mapsizevertical_mobile'])?$_POST['mapsizevertical_mobile']:$mapSizeVerticalMobile,
     "movemapsphere_group"                => isset($_POST['movemapsphere_group']['movemapsphere'])?$_POST['movemapsphere_group']['movemapsphere']:$mapdata[0]->getMoveMapSphere_BaseMap(),
     "usegis_group[usegis]"               => isset($_POST['usegis_group']['usegis'])?$_POST['usegis_group']['usegis']:$selectusegis,
     "movemapsphere_group[movemapsphere]" => isset($_POST['movemapsphere_group']['movemapsphere'])?$_POST['movemapsphere_group']['movemapsphere']:$mapdata[0]->getMoveMapSphere_BaseMap(),
     "diffx"                              => isset($_POST['diffx'])?$_POST['diffx']:$mapdata[0]->getDiffX_BaseMap(),
-    "diffy"                              => isset($_POST['diffy'])?$_POST['diffy']:$mapdata[0]->getDiffY_BaseMap()
+    "diffy"                              => isset($_POST['diffy'])?$_POST['diffy']:$mapdata[0]->getDiffY_BaseMap(),
+    "diffx_mobile"                              => isset($_POST['diffx_mobile'])?$_POST['diffx_mobile']:$mapdata[0]->getDiffXMobile_BaseMap(),
+    "diffy_mobile"                              => isset($_POST['diffy_mobile'])?$_POST['diffy_mobile']:$mapdata[0]->getDiffYMobile_BaseMap()
 );
 
 $o_form->setDefaults($form_def);
@@ -141,6 +159,8 @@ $o_form->addElement("text",             "endx",                $label['colTitleA
 $o_form->addElement("text",             "endy",                $label['colTitleA03'], array("size"=>30, "maxlength"=>30, "class"=>"fs12_black"));
 $o_form->addElement("text",             "mapsizehorizontal",   $label['colTitleA04'], array("size"=>30, "maxlength"=>30, "class"=>"fs12_black", "onchange"=>"alert('".$o_resource->getValue("G03006M038")."')"));
 $o_form->addElement("text",             "mapsizevertical",     $label['colTitleA04'], array("size"=>30, "maxlength"=>30, "class"=>"fs12_black", "onchange"=>"alert('".$o_resource->getValue("G03006M038")."')"));
+$o_form->addElement("text",             "mapsizehorizontal_mobile",   $label['colTitleA04'], array("size"=>30, "maxlength"=>30, "class"=>"fs12_black", "onchange"=>"alert('".$o_resource->getValue("G03006M038")."')"));
+$o_form->addElement("text",             "mapsizevertical_mobile",     $label['colTitleA04'], array("size"=>30, "maxlength"=>30, "class"=>"fs12_black", "onchange"=>"alert('".$o_resource->getValue("G03006M038")."')"));
 $array_movemapsphere[] =& HTML_QuickForm::createElement("radio", "movemapsphere", null, $label['movemap01'], KAKIKOMAP_MOVEMAPSPHERE_NORMAL);
 $array_movemapsphere[] =& HTML_QuickForm::createElement("radio", "movemapsphere", null, $label['movemap02'], KAKIKOMAP_MOVEMAPSPHERE_2FLAC);
 $array_movemapsphere[] =& HTML_QuickForm::createElement("radio", "movemapsphere", null, $label['movemap03'], KAKIKOMAP_MOVEMAPSPHERE_3FLAC);
@@ -149,9 +169,12 @@ $o_form->addGroup($array_movemapsphere, "movemapsphere_group", $label['colTitleA
 $o_form->addElement("header",           "header",              $label['topTitle1']);
 $o_form->addElement("text",             "diffx",               $label['colTitleB02'], array("size"=>30, "maxlength"=>30, "class"=>"fs12_black"));
 $o_form->addElement("text",             "diffy",               $label['colTitleB02'], array("size"=>30, "maxlength"=>30, "class"=>"fs12_black"));
+$o_form->addElement("text",             "diffx_mobile",        $label['colTitleB02'], array("size"=>30, "maxlength"=>30, "class"=>"fs12_black"));
+$o_form->addElement("text",             "diffy_mobile",        $label['colTitleB02'], array("size"=>30, "maxlength"=>30, "class"=>"fs12_black"));
 // マップファイルの存在チェック(ファイルが無い場合はヘルプボタンを出さない)
 if (mapFileCheck()) {
-	$o_form->addElement("link",         "helplink",            null, "javascript:open_subwindow_nonsubmit('./gishelper.php','subwindow',700,650)", $label['helpLink']);
+	$o_form->addElement("link",         "helplink",            null, "javascript:open_subwindow_nonsubmit('./gishelper.php?viewMode=pc','subwindow',700,650)", $label['helpLink']);
+	$o_form->addElement("link",         "helplink_mobile",            null, "javascript:open_subwindow_nonsubmit('./gishelper.php?viewMode=mobile','subwindow',700,650)", $label['helpLink']);
 }
 // -- GISあり項目 --
 $o_form->addElement("text",   "gisfile", str_replace("\\n", "<br>", $label['colTitleB01']), array("size"=>30, "class"=>"fs12_black", "readonly"));
@@ -180,10 +203,15 @@ $o_form->addRule("endy",              $o_resource->getValue("G03006M011"), "nume
 $o_form->addRule("endy",              $o_resource->getValue("G03006M012"), "maxlength_valid",	20);
 $o_form->addRule("mapsizehorizontal", $o_resource->getValue("G03006M013"), "required", null);
 $o_form->addRule("mapsizehorizontal", $o_resource->getValue("G03006M014"), "numeric",  null);
+$o_form->addRule("mapsizehorizontal_mobile", $o_resource->getValue("G03006M013"), "required", null);
+$o_form->addRule("mapsizehorizontal_mobile", $o_resource->getValue("G03006M014"), "numeric",  null);
 //$o_form->addRule("mapsizehorizontal", $o_resource->getValue("G03004M015"), "num_sphere_valid", array(1, 2000));
 $o_form->addRule("mapsizevertical",   $o_resource->getValue("G03006M016"), "required", null);
 $o_form->addRule("mapsizevertical",   $o_resource->getValue("G03006M017"), "numeric",  null);
 $o_form->addRule("mapsizevertical",   $o_resource->getValue("G03006M018"), "num_sphere_valid", array(1, 2000));
+$o_form->addRule("mapsizevertical_mobile",   $o_resource->getValue("G03006M016"), "required", null);
+$o_form->addRule("mapsizevertical_mobile",   $o_resource->getValue("G03006M017"), "numeric",  null);
+$o_form->addRule("mapsizevertical_mobile",   $o_resource->getValue("G03006M018"), "num_sphere_valid", array(1, 2000));
 
 // 地図の座標　左下・中心の大小関係
 $o_form->addRule(array("startx", "endx"), $o_resource->getValue("G03006M019"), "compare", "lt");
@@ -206,9 +234,13 @@ if ($usegis_on) {
 //	$o_form->addRule("diffx",             $o_resource->getValue("G03006M021"), "required", null);
 	$o_form->addRule("diffx",             $o_resource->getValue("G03006M022"), "numeric",  null);
 	$o_form->addRule("diffx",             $o_resource->getValue("G03006M023"), "maxlength_valid",	20);
+	$o_form->addRule("diffx_mobile",      $o_resource->getValue("G03006M022"), "numeric",  null);
+	$o_form->addRule("diffx_mobile",      $o_resource->getValue("G03006M023"), "maxlength_valid",	20);
 //	$o_form->addRule("diffy",             $o_resource->getValue("G03006M024"), "required", null);
 	$o_form->addRule("diffy",             $o_resource->getValue("G03006M025"), "numeric",  null);
 	$o_form->addRule("diffy",             $o_resource->getValue("G03006M026"), "maxlength_valid",	20);
+	$o_form->addRule("diffy_mobile",      $o_resource->getValue("G03006M025"), "numeric",  null);
+	$o_form->addRule("diffy_mobile",      $o_resource->getValue("G03006M026"), "maxlength_valid",	20);
 }
 
 $errorMessage = "";
@@ -437,7 +469,7 @@ function updateRecode_GIS_Off($o_service, $curDir, $input_mapno) {
 }
 
 /**
-* 関数概要：ベースマップ設定内容更新(GIS使用無し)
+* 関数概要：ベースマップ設定内容更新(GIS使用有り)
 * 処理詳細：入力された内容をデータベースへ更新する
 *           ・ベースマップ管理テーブル
 *           ・マップ詳細管理テーブル
@@ -446,8 +478,8 @@ function updateRecode_GIS_Off($o_service, $curDir, $input_mapno) {
 * @戻値： boolean TRUE :正常
 *      ：         FALSE:異常
 * @作成日/作成者：2006/09/01 (IIS)H.Keta
-* @更新日/更新者：
-* @更新内容：
+* @更新日/更新者：2007/03/04 (IIS)J.Fujikawa
+* @更新内容：携帯用項目追加
 */
 function updateRecode_GIS_On($o_service,$curDir) {
 
@@ -462,9 +494,13 @@ function updateRecode_GIS_On($o_service,$curDir) {
 	$post_data['P_USEGIS'] = $_POST['usegis_group']['usegis'];
 	$post_data['P_MAPSIZE_HORIZONTAL'] = $_POST['mapsizehorizontal'];
 	$post_data['P_MAPSIZE_VERTICAL'] = $_POST['mapsizevertical'];
+	$post_data['P_MAPSIZE_HORIZONTAL_MOBILE'] = $_POST['mapsizehorizontal_mobile'];
+	$post_data['P_MAPSIZE_VERTICAL_MOBILE'] = $_POST['mapsizevertical_mobile'];
 	$post_data['P_MOVEMAP_SPHERE'] = $_POST['movemapsphere_group']['movemapsphere'];
 	$post_data['P_DIFF_X'] = $_POST['diffx'];
 	$post_data['P_DIFF_Y'] = $_POST['diffy'];
+	$post_data['P_DIFF_X_MOBILE'] = $_POST['diffx_mobile'];
+	$post_data['P_DIFF_Y_MOBILE'] = $_POST['diffy_mobile'];
 
 	$rtn = $o_service->setBaseMap_GIS_On($post_data);
 	if ($rtn) {
@@ -647,8 +683,8 @@ function basemapInputCheck($o_resource, &$input_mapno){
 * @引数： 
 * @戻値： 
 * @作成日/作成者：2006/09/01 (IIS)K.Shimomura
-* @更新日/更新者：
-* @更新内容：
+* @更新日/更新者：2007/03/01 (IIS)J.Fujikawa
+* @更新内容：携帯用項目追加
 */
 //function writeIniFile() {
 function writeIniFile($curDir, $input_mapno) {
@@ -673,6 +709,9 @@ function writeIniFile($curDir, $input_mapno) {
 	// 画面表示地図サイズ
 	$map_width =& $setting->searchPath(array("MAP_WIDTH"));
 	$map_height =& $setting->searchPath(array("MAP_HEIGHT"));
+	// 画面表示地図サイズ(携帯用)
+	$map_width_mobile =& $setting->searchPath(array("MAP_WIDTH_MOBILE"));
+	$map_height_mobile =& $setting->searchPath(array("MAP_HEIGHT_MOBILE"));
 	// 地図の動く幅
 	$map_move =& $setting->searchPath(array("MAP_MOVE"));
 	// 初期表示座標
@@ -690,6 +729,8 @@ function writeIniFile($curDir, $input_mapno) {
 	$map_file_name = & $setting->searchPath(array("MAP_FILE_NAME"));
 	// 中心スケール(GISエンジン)
 	$map_center = & $setting->searchPath(array("MAP_CENTER"));
+	// 中心スケール(GISエンジン:携帯用)
+	$map_center_mobile = & $setting->searchPath(array("MAP_CENTER_MOBILE"));
 
 	// 設定
 	// マップ種別
@@ -697,6 +738,9 @@ function writeIniFile($curDir, $input_mapno) {
 	// 画面表示地図サイズ
 	$map_width->setContent($_POST['mapsizehorizontal']);
 	$map_height->setContent($_POST['mapsizevertical']);
+	// 画面表示地図サイズ(携帯用)
+	$map_width_mobile->setContent($_POST['mapsizehorizontal_mobile']);
+	$map_height_mobile->setContent($_POST['mapsizevertical_mobile']);
 	// 地図の動く幅
 	switch ($_POST['movemapsphere_group']['movemapsphere']) {
 		case KAKIKOMAP_MOVEMAPSPHERE_NORMAL:
@@ -749,6 +793,8 @@ function writeIniFile($curDir, $input_mapno) {
 		}
 		// 中心スケール
 		$map_center->setContent($_POST['diffx'] . "," . $_POST['diffy']);
+		// 中心スケール(携帯用)
+		$map_center_mobile->setContent($_POST['diffx_mobile'] . "," . $_POST['diffy_mobile']);
 	}
 
 	$rtn = $config->writeConfig($fpath, "inicommented");
