@@ -3,8 +3,8 @@
 * @パッケージ：-
 * @作者：
 * @作成日/作成者：2006/09/01 (IIS)S.Komukai
-* @更新日/更新者：
-* @バージョン：1.0.0
+* @更新日/更新者：2007/03/15 (IIS)S.Komukai
+* @バージョン：1.1.0
 *
 * Copyright (c) 2006 Iwate Information System Co.,Ltd. All Rights Reserved.       
 * You may see the License at LICENSE_EN.txt(English) or LICENSE_JA.txt(Japanese). 
@@ -18,6 +18,9 @@ var fusen = "hidden";
 // 付箋の表示位置修正
 var xSpace = 5;
 var ySpace = -11;
+// 地図ダブルクリック座標グローバル変数
+var _doubleClickX;               // ダブルクリック時のX座標
+var _doubleClickY;               // ダブルクリック時のY座標
 
 /**
 * 関数概要：マップへのメモ表示処理
@@ -181,8 +184,9 @@ function switchContributionLayer()
 * @戻値： なし
 *
 * @作成日/作成者：2006/09/01 (IIS)S.Komukai
-* @更新日/更新者：
+* @更新日/更新者：2007/03/15 (IIS)S.Komukai
 * @更新内容：
+*   2007/03/15 ダブルクリックによる地図移動追加(ダブルクリックイベント)
 */
 function onLoadSetting(){
 //	fusen = "hidden";
@@ -190,6 +194,46 @@ function onLoadSetting(){
 	// NowLoading対応
 	document.getElementById('nowLoading').style.visibility='hidden';
 	document.getElementById('contentsBody').style.visibility='visible';
+
+
+    // mapAreaダブルクリックイベント設定
+    if(document.all){    
+        // IE
+        document.getElementById('mapArea').ondblclick = function (e)
+        {
+	        var offsetX = event.x;
+	        var offsetY = event.y;
+	
+	        // MacIEの座標補正
+	        if (navigator.userAgent.indexOf("Mac") != -1) {
+	            offsetX += document.body.scrollLeft;
+	            offsetY += document.body.scrollTop;
+	            offsetX -= document.getElementById('mapParent').offsetLeft;
+	            offsetY -= document.getElementById('mapParent').offsetTop;
+	        }
+	        _doubleClickX = offsetX;
+	        _doubleClickY = offsetY;
+
+			moveInMapByDoubleClick();
+			return false;
+	    }
+
+    }else if ( (document.layers || document.getElementById) && !document.all) {
+        // NN7,Safari,Firefox
+        document.getElementById('mapArea').ondblclick= function (e){
+//            var offsetX = e.layerX;
+//            var offsetY = e.layerY;
+	        var offsetX = e.pageX - document.getElementById('mapParent').offsetLeft;
+	        var offsetY = e.pageY - document.getElementById('mapParent').offsetTop;
+	
+	        _doubleClickX = offsetX;
+	        _doubleClickY = offsetY;
+
+			moveInMapByDoubleClick();
+			return false;
+	    }
+    }	
+	
 	
 }
 
@@ -586,4 +630,174 @@ function imiDisplaySwitch(mode, radioType, layerId, memoTypeId, colorId){
 		}
 	}
 
-}
\ No newline at end of file
+}
+
+/**
+* 関数概要：MapAreaダブルクリックによる中心表示
+* 処理詳細：地図上でダブルクリックした位置を中心表示する。
+*
+* @引数： なし
+* @戻値： なし
+*
+* @作成日/作成者：2007/03/15 (IIS)S.Komukai
+* @更新日/更新者：
+* @更新内容：
+*/
+function moveInMapByDoubleClick()
+{
+	var clickX = 0.000000;
+	var clickY = 0.000000;
+
+	mapRange = document.kakikoFromMap.mapext.value.split(" ");
+
+	// クリックされた座標の算出(x:clickX, y:clickY)
+	clickX = parseFloat(mapRange[0]) 
+				+ ((mapRange[2] - mapRange[0]) * (_doubleClickX / document.kakikoFromMap.area_width.value));
+
+	if(document.kakikoFromMap.mapType.value == 0){
+		// GIS版Y座標
+		clickY = parseFloat(mapRange[1]) 
+					+ ((mapRange[3] - mapRange[1]) * ((document.kakikoFromMap.area_height.value - _doubleClickY) / document.kakikoFromMap.area_height.value));
+	}else{
+		// イメージ版Y座標
+		clickY = parseFloat(mapRange[1]) 
+					+ ((mapRange[3] - mapRange[1]) * (document.kakikoFromMap.area_height.value / document.kakikoFromMap.area_height.value));
+	}
+
+
+	minx = Math.round((clickX - ((mapRange[2] - mapRange[0]) / 2)) * 1000000) / 1000000;
+	miny = Math.round((clickY - ((mapRange[3] - mapRange[1]) / 2)) * 1000000) / 1000000;
+	maxx = Math.round((clickX + ((mapRange[2] - mapRange[0]) / 2)) * 1000000) / 1000000;
+	maxy = Math.round((clickY + ((mapRange[3] - mapRange[1]) / 2)) * 1000000) / 1000000;
+
+
+	var path = window.location.pathname;
+	var dir = path.substring(0, path.lastIndexOf("/") + 1);
+	window.parent.map.location.href= dir + "map.php?"
+		+ "area_height=" + document.kakikoFromMap.area_height.value 
+		+ "&area_width=" + document.kakikoFromMap.area_width.value 
+		+ "&click_x=" + document.kakikoFromMap.click_x.value 
+		+ "&click_y=" + document.kakikoFromMap.click_y.value 
+		+ "&mapext=" + minx + "+" + miny + "+" + maxx + "+" + maxy
+		+ "&scale=" + document.kakikoFromMap.scale.value 
+		+ "&searchNew=" + document.kakikoFromMap.searchNew.value 
+		+ "&searchFromDate=" + document.kakikoFromMap.searchFromDate.value 
+		+ "&searchToDate=" + document.kakikoFromMap.searchToDate.value 
+		+ "&searchWord=" + document.kakikoFromMap.searchWord.value ;
+
+}
+
+/**
+* 関数概要：メモ投稿付箋の状態設定
+* 処理詳細：onLoadイベント後にメモ投稿付箋の状態設定をする
+*
+* @引数： なし
+* @戻値： なし
+*
+* @作成日/作成者：2006/09/01 (IIS)S.Komukai
+* @更新日/更新者：2007/03/15 (IIS)S.Komukai
+* @更新内容：
+*   2007/03/15 ダブルクリックによる地図移動追加(ダブルクリックイベント)
+*/
+function onLoadSettingPos(){
+//	fusen = "hidden";
+
+	// NowLoading対応
+	document.getElementById('nowLoading').style.visibility='hidden';
+	document.getElementById('contentsBody').style.visibility='visible';
+
+
+    // mapAreaダブルクリックイベント設定
+    if(document.all){    
+        // IE
+        document.getElementById('mapArea').ondblclick = function (e)
+        {
+	        var offsetX = event.x;
+	        var offsetY = event.y;
+	
+	        // MacIEの座標補正
+	        if (navigator.userAgent.indexOf("Mac") != -1) {
+	            offsetX += document.body.scrollLeft;
+	            offsetY += document.body.scrollTop;
+	            offsetX -= document.getElementById('mapParent').offsetLeft;
+	            offsetY -= document.getElementById('mapParent').offsetTop;
+	        }
+	        _doubleClickX = offsetX;
+	        _doubleClickY = offsetY;
+
+			moveInMapByDoubleClickPos();
+			return false;
+	    }
+
+    }else if ( (document.layers || document.getElementById) && !document.all) {
+        // NN7,Safari,Firefox
+        document.getElementById('mapArea').ondblclick= function (e){
+//            var offsetX = e.layerX;
+//            var offsetY = e.layerY;
+	        var offsetX = e.pageX - document.getElementById('mapParent').offsetLeft;
+	        var offsetY = e.pageY - document.getElementById('mapParent').offsetTop;
+	
+	        _doubleClickX = offsetX;
+	        _doubleClickY = offsetY;
+
+			moveInMapByDoubleClickPos();
+			return false;
+	    }
+    }	
+	
+	
+}
+/**
+* 関数概要：MapAreaダブルクリックによる中心表示
+* 処理詳細：地図上でダブルクリックした位置を中心表示する。
+*
+* @引数： なし
+* @戻値： なし
+*
+* @作成日/作成者：2007/03/15 (IIS)S.Komukai
+* @更新日/更新者：
+* @更新内容：
+*/
+function moveInMapByDoubleClickPos()
+{
+	var clickX = 0.000000;
+	var clickY = 0.000000;
+
+	mapRange = document.kakikoFromMap.mapext.value.split(" ");
+
+	// クリックされた座標の算出(x:clickX, y:clickY)
+	clickX = parseFloat(mapRange[0]) 
+				+ ((mapRange[2] - mapRange[0]) * (_doubleClickX / document.kakikoFromMap.area_width.value));
+
+	if(document.kakikoFromMap.mapType.value == 0){
+		// GIS版Y座標
+		clickY = parseFloat(mapRange[1]) 
+					+ ((mapRange[3] - mapRange[1]) * ((document.kakikoFromMap.area_height.value - _doubleClickY) / document.kakikoFromMap.area_height.value));
+	}else{
+		// イメージ版Y座標
+		clickY = parseFloat(mapRange[1]) 
+					+ ((mapRange[3] - mapRange[1]) * (document.kakikoFromMap.area_height.value / document.kakikoFromMap.area_height.value));
+	}
+
+
+	minx = Math.round((clickX - ((mapRange[2] - mapRange[0]) / 2)) * 1000000) / 1000000;
+	miny = Math.round((clickY - ((mapRange[3] - mapRange[1]) / 2)) * 1000000) / 1000000;
+	maxx = Math.round((clickX + ((mapRange[2] - mapRange[0]) / 2)) * 1000000) / 1000000;
+	maxy = Math.round((clickY + ((mapRange[3] - mapRange[1]) / 2)) * 1000000) / 1000000;
+
+
+	var path = window.location.pathname;
+	var dir = path.substring(0, path.lastIndexOf("/") + 1);
+	window.parent.map.location.href= dir + "positionmap.php?"
+		+ "area_height=" + document.kakikoFromMap.area_height.value 
+		+ "&area_width=" + document.kakikoFromMap.area_width.value 
+		+ "&click_x=" + document.kakikoFromMap.click_x.value 
+		+ "&click_y=" + document.kakikoFromMap.click_y.value 
+		+ "&mapext=" + minx + "+" + miny + "+" + maxx + "+" + maxy
+		+ "&scale=" + document.kakikoFromMap.scale.value 
+		+ "&searchNew=" + document.kakikoFromMap.searchNew.value 
+		+ "&searchFromDate=" + document.kakikoFromMap.searchFromDate.value 
+		+ "&searchToDate=" + document.kakikoFromMap.searchToDate.value 
+		+ "&searchWord=" + document.kakikoFromMap.searchWord.value ;
+
+}
