@@ -471,6 +471,90 @@ $LOG->debug("mapext : ".$mapext."<br><BR>");
 		return $scaleString; 
 	}
 	
+	/**
+	* 関数概要：地図拡大 MAPEXT引数取得(GIS版)
+	* 処理詳細：GIS版の地図拡大用のMAPEXT引数を取得します
+	*
+    * @引数：なし
+	* @戻値：(O) 拡大後のmapext引数
+	* @作成日/作成者：2007/03/01 (IIS)J.Fujikawa
+	* @更新日/更新者：
+	* @更新内容：
+	*/
+    function get_mapextZoomInStringGIS(){
+    	
+    	$scaleString = array();
+		
+		$crateX = 0;
+		$crateY = 0;
+
+    	$base_minX = 0;		// 計算基準とするminX
+    	$base_minY = 0;		// 計算基準とするminy
+    	$base_maxX = 0;		// 計算基準とするmaxx
+    	$base_maxY = 0;		// 計算基準とするmaxy
+		
+		// スケール計算時に基準となるX方向の距離
+	    $DistanceX = $this->_centerX - $this->_minX;	
+	    // スケール計算時に基準となるY方向の距離
+	    $DistanceY = $this->_centerY - $this->_minY;	
+		$dispString ="";
+
+		// 地図範囲リンク算出のベースとなる座標
+		$base_minX = $this->_centerX - $DistanceX;
+		$base_minY = $this->_centerY - $DistanceY;
+		$base_maxX = $this->_centerX + $DistanceX;
+		$base_maxY = $this->_centerY + $DistanceY;
+		
+		// 2
+		$crateX = $this->_centerX - ($this->_centerX - $base_minX) / 2;
+		$crateY = $this->_centerY - ($this->_centerY - $base_minY) / 2;
+    	$mapext = "&mapext=".$crateX."+".$crateY."+"
+    		.($crateX +(($base_maxX - $base_minX) / 2)."+".($crateY + (($base_maxY - $base_minY) / 2)));
+
+		return $mapext; 
+    }
+	/**
+	* 関数概要：地図縮小 MAPEXT引数取得(GIS版)
+	* 処理詳細：GIS版の地図縮小用のMAPEXT引数を取得します
+	*
+    * @引数：なし
+	* @戻値：(O) 縮小後のmapext引数
+	* @作成日/作成者：2007/03/01 (IIS)J.Fujikawa
+	* @更新日/更新者：
+	* @更新内容：
+	*/
+    function get_mapextZoomOutStringGIS(){
+    	
+    	$scaleString = array();
+		
+		$crateX = 0;
+		$crateY = 0;
+
+    	$base_minX = 0;		// 計算基準とするminX
+    	$base_minY = 0;		// 計算基準とするminy
+    	$base_maxX = 0;		// 計算基準とするmaxx
+    	$base_maxY = 0;		// 計算基準とするmaxy
+		
+		// スケール計算時に基準となるX方向の距離
+	    $DistanceX = $this->_centerX - $this->_minX;	
+	    // スケール計算時に基準となるY方向の距離
+	    $DistanceY = $this->_centerY - $this->_minY;	
+		$dispString ="";
+
+		// 地図範囲リンク算出のベースとなる座標
+		$base_minX = $this->_centerX - $DistanceX;
+		$base_minY = $this->_centerY - $DistanceY;
+		$base_maxX = $this->_centerX + $DistanceX;
+		$base_maxY = $this->_centerY + $DistanceY;
+		
+		// 1/2
+		$crateX = $this->_centerX - (($this->_centerX - $base_minX) * 2);
+		$crateY = $this->_centerY - (($this->_centerY - $base_minY) * 2);
+    	$mapext = "&mapext=".$crateX."+".$crateY."+"
+    		.($crateX +(($base_maxX - $base_minX) * 2)."+".($crateY + (($base_maxY - $base_minY) * 2)));
+
+		return $mapext; 
+    }
 	
 }
 ?>
