@@ -54,6 +54,7 @@ class MemoCommentTreeAccess extends TableAccess {
     *              $searchKey['from']	- 対象期間（from）
     *              $searchKey['to']		- 対象期間（to）
     *              $searchKey['word']	- 語句
+    *              $searchKey['displaymemotype']	- 表示対象メモ種類
     *              $searchKey['minx']	- 範囲座標（X緯度最小）
     *              $searchKey['maxx']	- 範囲座標（X緯度最大）
     *              $searchKey['miny']	- 範囲座標（Y経度最小）
@@ -95,7 +96,22 @@ class MemoCommentTreeAccess extends TableAccess {
 								//語句を追加する
 								$sql .= " AND ( dt.memotitle like '%".$searchKey['word']."%'";
 								$sql .= " OR dt.memotext like '%".$searchKey['word']."%' )";
-							}							
+							}
+							if 	(is_null($searchKey['displaymemotype']) == false){
+								//表示対象メモ種類を追加する
+								$dispmemoarray = split(" ", $searchKey['displaymemotype']);
+								$memotypesql = null;
+								foreach($dispmemoarray as $cur){
+									if (is_null($memotypesql) == true){
+										$memotypesql = " AND type.memotypeid IN (".$cur;
+									}else{
+										$memotypesql .= ",".$cur;
+									}
+								}
+								$memotypesql .= " )";
+								$sql .= $memotypesql;
+								
+							}
 							if (is_null($searchKey['minx']) == false){
 								//緯度最小を追加する
 								$sql .= " AND po.longitude >=".$searchKey['minx'];
@@ -140,7 +156,22 @@ class MemoCommentTreeAccess extends TableAccess {
 								//語句を追加する
 								$sql .= " AND ( dt.memotitle like '%".$searchKey['word']."%'";
 								$sql .= " OR dt.memotext like '%".$searchKey['word']."%' )";
-							}							
+							}
+							if 	(is_null($searchKey['displaymemotype']) == false){
+								//表示対象メモ種類を追加する
+								$dispmemoarray = split(" ", $searchKey['displaymemotype']);
+								$memotypesql = null;
+								foreach($dispmemoarray as $cur){
+									if (is_null($memotypesql) == true){
+										$memotypesql = " AND type.memotypeid IN (".$cur;
+									}else{
+										$memotypesql .= ",".$cur;
+									}
+								}
+								$memotypesql .= " )";
+								$sql .= $memotypesql;
+								
+							}
 							if (is_null($searchKey['minx']) == false){
 								//緯度最小を追加する
 								$sql .= " AND po.longitude >= ".$searchKey['minx'];
@@ -166,10 +197,10 @@ class MemoCommentTreeAccess extends TableAccess {
 							//最新件数
 							$sql .= " ORDER BY adddatetime_m desc , commentid";
 						}else{
-							$sql .= " ORDER BY memoid, commentid";						
+							$sql .= " ORDER BY memoid desc, commentid";						
 						}
 					}else{
-						$sql .= " ORDER BY memoid, commentid";
+						$sql .= " ORDER BY memoid desc, commentid";
 					}
 				
 					
@@ -209,7 +240,22 @@ class MemoCommentTreeAccess extends TableAccess {
 								//語句を追加する
 								$sql .= " AND ( dt.memotitle like '%".$searchKey['word']."%'";
 								$sql .= " OR dt.memotext like '%".$searchKey['word']."%' )";
-							}							
+							}
+							if 	(is_null($searchKey['displaymemotype']) == false){
+								//表示対象メモ種類を追加する
+								$dispmemoarray = split(" ", $searchKey['displaymemotype']);
+								$memotypesql = null;
+								foreach($dispmemoarray as $cur){
+									if (is_null($memotypesql) == true){
+										$memotypesql = " AND type.memotypeid IN (".$cur;
+									}else{
+										$memotypesql .= ",".$cur;
+									}
+								}
+								$memotypesql .= " )";
+								$sql .= $memotypesql;
+								
+							}
 							if (is_null($searchKey['minx']) == false){
 								//緯度最小を追加する
 								$sql .= " AND po.longitude >= ".$searchKey['minx'];
@@ -258,7 +304,22 @@ class MemoCommentTreeAccess extends TableAccess {
 								//語句を追加する
 								$sql .= " AND ( dt.memotitle like '%".$searchKey['word']."%'";
 								$sql .= " OR dt.memotext like '%".$searchKey['word']."%' )";
-							}							
+							}
+							if 	(is_null($searchKey['displaymemotype']) == false){
+								//表示対象メモ種類を追加する
+								$dispmemoarray = split(" ", $searchKey['displaymemotype']);
+								$memotypesql = null;
+								foreach($dispmemoarray as $cur){
+									if (is_null($memotypesql) == true){
+										$memotypesql = " AND type.memotypeid IN (".$cur;
+									}else{
+										$memotypesql .= ",".$cur;
+									}
+								}
+								$memotypesql .= " )";
+								$sql .= $memotypesql;
+								
+							}
 							if (is_null($searchKey['minx']) == false){
 								//緯度最小を追加する
 								$sql .= " AND po.longitude >=".$searchKey['minx'];
@@ -283,10 +344,10 @@ class MemoCommentTreeAccess extends TableAccess {
 							//最新件数
 							$sql .= " ORDER BY adddatetime_m desc , commentid";
 						}else{
-							$sql .= " ORDER BY memoid, commentid";						
+							$sql .= " ORDER BY memoid desc, commentid";						
 						}
 					}else{
-						$sql .= " ORDER BY memoid, commentid";
+						$sql .= " ORDER BY memoid desc, commentid";
 					}					
 		}
 			$this->setRecordSet($db->executeQuery($sql));
