@@ -985,6 +985,57 @@ class ContentsViewService extends KakikoService {
 
 	}
 
+	/**
+	 *	関数名：メモ／コメント更新処理(携帯用)
+     * @引数：(I) $targetDetail		メモ詳細テーブル対象列(条件列/更新列)指定用データオブジェクト
+     * @引数：(I) $targetPosition	メモ位置テーブル対象列(条件列/更新列)指定用データオブジェクト  
+     * @引数：(I) $targetComment	コメントテーブル対象列(条件列/更新列)指定用データオブジェクト
+     * @引数：(I) $dataArray    	設定値(条件値/更新値)指定用データオブジェクト
+     * @引数：(O) $updDate			更新時刻
+     * @戻値：$bool			- true  正常更新
+     *                      - false 異常
+     * @作成日/作成者：2007/03/01 (IIS)J.Fujikawa
+     * @更新日/更新者：
+	 *            
+     */
+	function updateMemoCommentDataByKeyMobile($targetDetail, $targetPosition, $targetComment, $dataArray, &$updDate) {
+		//初期化
+		$flg = false;
+		$rtn = false;
+		$memo_table_access = null;
+		$memodata = null;
+
+		//更新用メソッドを呼び出す
+		$flg = $this->updateMemoCommentDataByKey($targetDetail, $targetPosition, $targetComment, $dataArray);
+		
+		//以下、更新時刻を取得する為にデータを取得する
+		// DBオブジェクトの生成
+		$this->createDBObject();
+		
+		$memo_table_access = new MemoDetailTableAccess($this->directryname);
+		$rtn = $memo_table_access->selectFindByKeyData($this->o_db, $dataArray["memoid"]);
+		if ($rtn != true) {
+			$this->o_db->rollback();
+			$memo_table_access->free();
+			$this->disconnectDB();
+			trigger_error($this->o_resource->getValue("S4_001_07"), E_USER_ERROR);
+			return false;
+		}
+		
+		$memodata = $memo_table_access->getOneData();
+		
+		//更新時刻を取得
+		if ($memodata != null){
+			$updDate = $memodata->getUpdateDateTime();
+		}
+		//開放
+		$memo_table_access->free();
+		// DB接続の切断
+		$this->disconnectDB();
+		
+		return $flg;
+	}
+
 	/**
 	 *	関数名：レイヤー表示順設定
      * @引数：(I) $userid           - ユーザID
@@ -1362,6 +1413,64 @@ class ContentsViewService extends KakikoService {
 		return true;
 	}
 
+	/**
+	 *	関数名：コメント新規登録(携帯用)
+     * @引数：(I) $commmetDataobj	- ユーザテーブル用データオブジェクト
+     *        (O) $newCommentId	  			- 新規発行されたコメントID
+     * @戻値：$bool			- true  正常登録
+     *                      - false 異常
+     * @作成日/作成者：2007/03/01 (IIS) J.Fujikawa
+     * @更新日/更新者：
+     */     
+	function insertCommnetMobile($commmetDataobj, &$newCommentId) {
+
+		// DBオブジェクトの生成
+		$this->createDBObject();
+
+		// トランザクション開始
+		$this->o_db->autoCommit(false);
+
+		// ユーザDBアクセスインスタンス生成
+		$comment_access = new CommentTableAccess($this->directryname);
+
+		// データ追加
+		$rtn = $comment_access->insertData($this->o_db, $commmetDataobj);
+		if ($rtn != true) {
+			$this->o_db->rollback();
+			$comment_access->free();
+			$this->disconnectDB();
+			trigger_error($this->o_resource->getValue("S4_001_22"), E_USER_ERROR);
+			return false;
+		}
+
+		//初期化
+		$commentid_seq = "";
+		
+		// -----------------------------------------------
+		// 発行したコメントIDをシーケンスから取得
+		// -----------------------------------------------
+		//select currval('xxxxxx_commenttable_commentid_seq') as commentid_seq
+		$dba = new KakikoDBAccess($this->o_db, 'dummy');
+		$dba->dba_executeQuery("select currval('".$this->directryname."_commenttable_commentid_seq') as commentid_seq");		
+		while($row = $dba->rs->fetchrow(DB_FETCHMODE_ASSOC)) {
+			$commentid_seq = isset($row['commentid_seq'])?$row['commentid_seq']:null;
+		}
+
+		// 解放
+		$comment_access->free();
+
+		// トランザクションコミット
+		$this->o_db->commit();
+
+		// DB接続の切断
+		$this->disconnectDB();
+		
+		// 返却値の設定
+		$newCommentId = $commentid_seq;
+
+		return true;
+	}
+
 	/**
 	 *	関数名：コメント更新処理
      * @引数：(I) $targetDataobj    - 対象列(条件列/更新列)指定用データオブジェクト
