@@ -719,7 +719,7 @@ class MapAdminService extends KakikoService {
      * @戻値：$bool			- true  正常処理
      *                      - false 異常
      * @作成日/作成者：2006/09/01 (IIS) K.Shimomura
-     * @更新日/更新者：
+     * @更新日/更新者：2007/03/01 (IIS) N.Soma 携帯機能追加
      * @使用方法：ベースマップ(GIS使用無し)の設定を行います。
 	 *            引数のポストデータには、'P_START_X'=>左下座標X
 	 *                                    'P_START_Y'=>左下座標Y
@@ -728,6 +728,8 @@ class MapAdminService extends KakikoService {
 	 *                                    'P_USEGIS'=>GIS使用区分
 	 *                                    'P_MAPSIZE_HORIZONTAL'=>地図サイズ横
 	 *                                    'P_MAPSIZE_VERTICAL'=>地図サイズ縦
+	 *                                    'P_MAPSIZE_HORIZONTAL_MOBILE'=>携帯地図サイズ横
+	 *                                    'P_MAPSIZE_VERTICAL_MOBILE'=>携帯地図サイズ縦
 	 *                                    'P_MOVEMAP_SPHERE'=>地図移動幅
 	 *                                    'P_MAPSTATUS'=>画像ファイルステータス
 	 *                                    'P_MAPIMAGE'=>画像ファイル区分
@@ -764,6 +766,10 @@ class MapAdminService extends KakikoService {
 		$targetBaseMapDataObj->setMapSizeVertical(VAL_TARGET);
 		$targetBaseMapDataObj->setDiffX(NULL_CHAR);
 		$targetBaseMapDataObj->setDiffY(NULL_CHAR);
+		$targetBaseMapDataObj->setMapSizeHorizontalMobile(VAL_TARGET);
+		$targetBaseMapDataObj->setMapSizeVerticalMobile(VAL_TARGET);
+		$targetBaseMapDataObj->setDiffXMobile(NULL_CHAR);
+		$targetBaseMapDataObj->setDiffYMobile(NULL_CHAR);
 		$targetBaseMapDataObj->setMoveMapSphere(VAL_TARGET);
 		$targetBaseMapDataObj->setUpdateDateTime(VAL_TARGET);
 
@@ -778,6 +784,8 @@ class MapAdminService extends KakikoService {
 		$valBaseMapDataObj->setEndY($post_data['P_END_Y']);
 		$valBaseMapDataObj->setMapSizeHorizontal($post_data['P_MAPSIZE_HORIZONTAL']);
 		$valBaseMapDataObj->setMapSizeVertical($post_data['P_MAPSIZE_VERTICAL']);
+		$valBaseMapDataObj->setMapSizeHorizontalMobile($post_data['P_MAPSIZE_HORIZONTAL_MOBILE']);
+		$valBaseMapDataObj->setMapSizeVerticalMobile($post_data['P_MAPSIZE_VERTICAL_MOBILE']);
 		$valBaseMapDataObj->setMoveMapSphere($post_data['P_MOVEMAP_SPHERE']);
 		$valBaseMapDataObj->setUpdateDateTime(date('Y/m/d H:i:s'));
 
@@ -1012,7 +1020,7 @@ class MapAdminService extends KakikoService {
      * @戻値：$bool			- true  正常処理
      *                      - false 異常
      * @作成日/作成者：2006/09/01 (IIS) K.Shimomura
-     * @更新日/更新者：
+     * @更新日/更新者：2007/03/01 (IIS) N.Soma 携帯機能追加
      * @使用方法：ベースマップ(GIS使用有り)の設定を行います。
 	 *            引数のポストデータには、'P_START_X'=>左下座標X
 	 *                                    'P_START_Y'=>左下座標Y
@@ -1021,6 +1029,8 @@ class MapAdminService extends KakikoService {
 	 *                                    'P_USEGIS'=>GIS使用区分
 	 *                                    'P_MAPSIZE_HORIZONTAL'=>地図サイズ横
 	 *                                    'P_MAPSIZE_VERTICAL'=>地図サイズ縦
+	 *                                    'P_MAPSIZE_HORIZONTAL_MOBILE'=>携帯地図サイズ横
+	 *                                    'P_MAPSIZE_VERTICAL_MOBILE'=>携帯地図サイズ縦
 	 *                                    'P_MOVEMAP_SPHERE'=>地図移動幅
 	 *                                    'P_DIFF_X'=>メモ中心表示地図の表示サイズX
 	 *                                    'P_DIFF_Y'=>メモ中心表示地図の表示サイズY
@@ -1042,6 +1052,8 @@ class MapAdminService extends KakikoService {
 		// メモ中心表示地図の表示サイズ
 		$diffx = (isset($post_data['P_DIFF_X']) && $post_data['P_DIFF_X'] != "")?$post_data['P_DIFF_X']:null;
 		$diffy = (isset($post_data['P_DIFF_Y']) && $post_data['P_DIFF_Y'] != "")?$post_data['P_DIFF_Y']:null;
+		$diffxMobile = (isset($post_data['P_DIFF_X_MOBILE']) && $post_data['P_DIFF_X_MOBILE'] != "")?$post_data['P_DIFF_X_MOBILE']:null;
+		$diffyMobile = (isset($post_data['P_DIFF_Y_MOBILE']) && $post_data['P_DIFF_Y_MOBILE'] != "")?$post_data['P_DIFF_Y_MOBILE']:null;
 
 		// 更新条件
 		$targetBaseMapDataObj->setDirectryName(WHERE_KEY);
@@ -1054,6 +1066,8 @@ class MapAdminService extends KakikoService {
 		$targetBaseMapDataObj->setEndY(VAL_TARGET);
 		$targetBaseMapDataObj->setMapSizeHorizontal(VAL_TARGET);
 		$targetBaseMapDataObj->setMapSizeVertical(VAL_TARGET);
+		$targetBaseMapDataObj->setMapSizeHorizontalMobile(VAL_TARGET);
+		$targetBaseMapDataObj->setMapSizeVerticalMobile(VAL_TARGET);
 		if (is_null($diffx)) {
 			$targetBaseMapDataObj->setDiffX(NULL_CHAR);
 		} else {
@@ -1064,6 +1078,16 @@ class MapAdminService extends KakikoService {
 		} else {
 			$targetBaseMapDataObj->setDiffY(VAL_TARGET);
 		}
+		if (is_null($diffxMobile)) {
+			$targetBaseMapDataObj->setDiffXMobile(NULL_CHAR);
+		} else {
+			$targetBaseMapDataObj->setDiffXMobile(VAL_TARGET);
+		}
+		if (is_null($diffyMobile)) {
+			$targetBaseMapDataObj->setDiffYMobile(NULL_CHAR);
+		} else {
+			$targetBaseMapDataObj->setDiffYMobile(VAL_TARGET);
+		}
 		$targetBaseMapDataObj->setMoveMapSphere(VAL_TARGET);
 		$targetBaseMapDataObj->setUpdateDateTime(VAL_TARGET);
 
@@ -1078,10 +1102,14 @@ class MapAdminService extends KakikoService {
 		$valBaseMapDataObj->setEndY($post_data['P_END_Y']);
 		$valBaseMapDataObj->setMapSizeHorizontal($post_data['P_MAPSIZE_HORIZONTAL']);
 		$valBaseMapDataObj->setMapSizeVertical($post_data['P_MAPSIZE_VERTICAL']);
+		$valBaseMapDataObj->setMapSizeHorizontalMobile($post_data['P_MAPSIZE_HORIZONTAL_MOBILE']);
+		$valBaseMapDataObj->setMapSizeVerticalMobile($post_data['P_MAPSIZE_VERTICAL_MOBILE']);
 		$valBaseMapDataObj->setMoveMapSphere($post_data['P_MOVEMAP_SPHERE']);
 		$valBaseMapDataObj->setUpdateDateTime(date('Y/m/d H:i:s'));
 		$valBaseMapDataObj->setDiffX($diffx);
 		$valBaseMapDataObj->setDiffY($diffy);
+		$valBaseMapDataObj->setDiffXMobile($diffxMobile);
+		$valBaseMapDataObj->setDiffYMobile($diffyMobile);
 
 		// ベースマップDBアクセスインスタンス生成
 		$table_access = new BaseMapTableAccess();
